@@ -24,6 +24,8 @@
 #include <pds/pdsrautils.h>
 #include <pds/pdsvector.h>
 
+#include <stdarg.h>
+#include <ctype.h>
 
 ////////////////////////////////////////////////////////////////////////////////
 ////  Trabajando con PdsVector                                              ////
@@ -54,6 +56,92 @@ PdsVector *pds_vector_new(PdsRaNatural Nel)
 	return Vector;
 }
 
+/** \fn PdsVector *pds_vector_new_array1d(const PdsRaReal *Array1D,PdsRaNatural N)
+ *  \brief Crea un vector de tipo PdsVector e inicia sus valores con el contenido
+ *  del arreglo de valores reales Array1D.
+ *  
+ *  exemplo:
+\code{.c}
+    PdsVector *V=NULL;
+    PdsRaReal A[]={-1,1.2,-3.0};
+    V=pds_vector_new_array1d(A,3);
+\endcode
+ *  \warning { Debes tener mucho cuidado con esta función, entregando el número de elementos adecuado. }
+ *  \param[in] Array1D Es el arreglo unidimensional que se usará como fuente.
+ *  \param[in] N Es el número de elementos del arreglo unidimensional que se usará como fuente.
+ *  \return Un puntero al vector de tipo PdsVector.
+ *  \ingroup PdsVectorGroup
+ */
+PdsVector *pds_vector_new_array1d(const PdsRaReal *Array1D,PdsRaNatural N)
+{
+	PdsVector *Vector=NULL;
+	PdsRaNatural i;
+
+	if(Array1D==NULL)	return NULL;
+
+	Vector=(PdsVector *)calloc(1,sizeof(PdsVector));
+	if(Vector==NULL) {return NULL;}
+
+	Vector->Nel=N;
+	Vector->V=(PdsRaReal *)calloc(Vector->Nel,sizeof(PdsRaReal));
+	if(Vector->V==NULL) 
+	{
+		free(Vector);
+		return NULL;
+	}
+	else
+	{
+		for(i=0;i<Vector->Nel;i++)	Vector->V[i]=Array1D[i];
+	}
+
+	return Vector;
+}
+
+
+/** \fn PdsVector *pds_vector_new_args(PdsRaNatural N,...)
+ *  \brief Crea un vector de tipo PdsVector e inicia sus valores con los valores
+ *  del segundo parametro de entrada en adelante.
+ *  
+ *  exemplo:
+\code{.c}
+    PdsVector *V=NULL;
+    V=pds_vector_new_args(3,-1,1.2,-3.0);
+\endcode
+ *  \warning { Debes tener mucho cuidado con esta función, entregando el número de elementos adecuado. }
+ *  \param[in] N Es el número de elementos del vector y el numero de parametros
+ *  de entrada adicionales.
+ *  \param[in] ... Parametros adicionales de tipo double.
+ *  \return Un puntero al vector de tipo PdsVector.
+ *  \ingroup PdsVectorGroup
+ */
+PdsVector *pds_vector_new_args(PdsRaNatural N,...)
+{
+	PdsVector *Vector=NULL;
+	PdsRaNatural i;
+
+    va_list args;          /* points to each unnamed arg in turn */
+
+	Vector=(PdsVector *)calloc(1,sizeof(PdsVector));
+	if(Vector==NULL) {return NULL;}
+
+	Vector->Nel=N;
+	Vector->V=(PdsRaReal *)calloc(Vector->Nel,sizeof(PdsRaReal));
+	if(Vector->V==NULL) 
+	{
+		free(Vector);
+		return NULL;
+	}
+	else
+	{
+        va_start( args, N );   /* make args point to 1st unnamed arg */
+
+		for(i=0;i<Vector->Nel;i++)	Vector->V[i]=(PdsRaReal)va_arg(args,double);
+
+        va_end( args );        /* clean up when done */
+	}
+
+	return Vector;
+}
 
 /** \fn PdsVector *pds_vector_new_vector(const PdsVector *VecSrc)
  *  \brief Crea un vector de tipo PdsVector e inicia sus valores con el contenido
@@ -112,7 +200,7 @@ PdsVector *pds_vector_new_load_data(const char* datafile)
 	fd=fopen(datafile,"r");
 	if(fd==NULL)	return NULL;
 
-	id=pds_ra_nelements_in_file(fd,&n);
+	id=pds_load_number_of_elements(fd,&n);
 	if(id==FALSE)	
 	{
 		fclose(fd);
@@ -165,7 +253,7 @@ PdsVector *pds_vector_new_load_data_line(const char* datafile,PdsRaNatural line)
 	fd=fopen(datafile,"r");
 	if(fd==NULL)	return NULL;
 
-	id=pds_ra_ncolumns_nlines_in_file(fd,&nc,&nl);
+	id=pds_load_number_of_columns_and_lines(fd,&nc,&nl);
 	if(id==FALSE)	
 	{
 		fclose(fd);
@@ -226,7 +314,7 @@ PdsVector *pds_vector_new_load_data_col(const char* datafile,PdsRaNatural col)
 	fd=fopen(datafile,"r");
 	if(fd==NULL)	return NULL;
 
-	id=pds_ra_ncolumns_nlines_in_file(fd,&nc,&nl);
+	id=pds_load_number_of_columns_and_lines(fd,&nc,&nl);
 	if(id==FALSE)	
 	{
 		fclose(fd);
@@ -1433,6 +1521,98 @@ PdsVector *pds_vector_new_blackman(PdsRaNatural N,PdsRaReal Alpha)
     return W;
 }
 
+
+/** \fn int pds_vector_octave_png_plot(const PdsVector *X,const PdsVector *Y,const char *labelx,const char *labely,const char *octfile,const char *pngfile)
+ *  \brief Imprime un vector Y vs X en un archivo png usando como intermedio un 
+ *  archivo *.m de octave.
+ *  \param[in] X Eje X del vector a imprimir.
+ *  Si X==NULL entonces se mostrara la gráfica usando el numero de muestras
+ *  como eje X.
+ *  \param[in] Y Eje Y del vector a imprimir.
+ *  \param[in] labelx Etiqueta del eje X.
+ *  \param[in] labely Etiqueta del eje Y.
+ *  \param[in] octfile Nombre del archivo *.m de octave que se usará de intermediario.
+ *  Si ostfile==NULL entonces se creará un fichero con nombre aleatorio y se 
+ *  borrará al terminar de crear el archivo png.
+ *  \param[in] pngfile Nombre del archivo *.png de salida.
+ *  \return TRUE si todo fue bien o FALSE si no, ejemplo punteros igual a NULL.
+ *  \ingroup PdsVectorGroup
+ */
+int pds_vector_octave_png_plot(const PdsVector *X,const PdsVector *Y,const char *labelx,const char *labely,const char *octfile,const char *pngfile)
+{
+	int i;
+    int  FONTSIZE =18;
+    char IMGSIZE[]="800,600";
+	FILE *fd=NULL;
+	char *orden=NULL;
+
+	if(Y==NULL)		return FALSE;
+	if(labelx==NULL)	return FALSE;
+	if(labely==NULL)	return FALSE;
+	if(pngfile==NULL)	return FALSE;
+    if(X!=NULL)	if(X->Nel!=Y->Nel)	return FALSE;
+
+
+    char *OCTAVEFILE=NULL;
+    if(octfile==NULL)
+    {
+        OCTAVEFILE=(char*)calloc(64,sizeof(char));
+        if(OCTAVEFILE==NULL)    return FALSE;
+        sprintf(OCTAVEFILE,"temp%d.m",rand());
+    }
+    else
+    {
+        OCTAVEFILE=strdup(octfile);
+        if(OCTAVEFILE==NULL)    return FALSE;
+    }
+
+
+
+	fd=fopen(OCTAVEFILE,"w");
+	if(fd==NULL)		return FALSE;
+	fprintf(fd,"Y=[");
+	for(i=0 ; i<Y->Nel ; i++)	fprintf(fd,"%e\t",Y->V[i]);
+	fprintf(fd,"];\n");
+    if(X==NULL)
+    {
+	    fprintf(fd,"N=length(Y);\n");
+	    fprintf(fd,"X=[0:N-1];\n");
+    }
+    else
+    {
+	    fprintf(fd,"X=[");
+    	for(i=0 ; i<X->Nel ; i++)	fprintf(fd,"%e\t",X->V[i]);
+    	fprintf(fd,"];\n");
+    }
+	fprintf(fd,"plot(X,Y,\'o-\');\n");
+	fprintf(fd,"grid on;\n");
+	fprintf(fd,"xlabel(\'%s\');\n",labelx);
+	fprintf(fd,"ylabel(\'%s\');\n",labely);
+	fprintf(fd,"xlim([min(X),max(X)]);\n");
+    fprintf(fd,"FONTSIZE=%d;\n",FONTSIZE);
+    fprintf(fd,"ha = gca(); \n");
+    fprintf(fd,"set(ha,'fontsize',FONTSIZE);\n");
+    fprintf(fd,"refresh();\n");
+	fprintf(fd,"print(\'%s\',\'-dpng\',\'-Farial:%d\',\'-S%s\');\n",pngfile,FONTSIZE,IMGSIZE);
+	fprintf(fd,"\n");
+	fprintf(fd,"\n");
+	fclose(fd);
+
+	orden=(char *)calloc(1,48+strlen(OCTAVEFILE));
+	if(orden==NULL)	return FALSE;
+	sprintf(orden,"octave --no-gui -q %s",OCTAVEFILE);
+	i=system(orden);
+
+
+    if(octfile==NULL)
+    {
+        remove(OCTAVEFILE); 
+    }
+    free(OCTAVEFILE);
+	return TRUE;
+}
+
+
 /** \fn void pds_vector_free(PdsVector *Vector)
  *  \brief Libera la memoria de un vector de tipo puntero PdsVector.
  *  \param[in,out] Vector El vector a liberar.
