@@ -61,7 +61,7 @@ extern "C" {
  */
 #define __MAX_CHAR_DATA_SIZE__	128
 
-/** \fn int pds_ra_ncolumns_nlines_in_file(FILE *fd,PdsRaNatural *nc,PdsRaNatural *nl)
+/** \fn int pds_load_number_of_columns_and_lines(FILE *fd,PdsRaNatural *nc,PdsRaNatural *nl)
  *  \brief Encuentra el número de columnas y de lineas dentro de un archivo.
  *  si el número de columnas no es constante dentro del archivo, la función 
  *  retorna FALSE, y carga en nc y nl la posición aproximada del error.
@@ -73,11 +73,11 @@ extern "C" {
  *  \return TRUE si todo fue bien o FALSE si no. (ej. fd==NULL)
  *  \ingroup PdsRaUtilsGroup
  */
-int pds_ra_ncolumns_nlines_in_file(FILE *fd,PdsRaNatural *nc,PdsRaNatural *nl);
+int pds_load_number_of_columns_and_lines(FILE *fd,PdsRaNatural *nc,PdsRaNatural *nl);
 
 
 
-/** \fn int pds_ra_nelements_in_file(FILE *fd,PdsRaNatural *n)
+/** \fn int pds_load_number_of_elements(FILE *fd,PdsRaNatural *n)
  *  \brief Encuentra el número de elementos dentro de un archivo.
  *  Al terminar coloca el fd en el inicio del archivo.
  *  Usa TAB o un salto de linea como delimitador de elemento.
@@ -86,7 +86,7 @@ int pds_ra_ncolumns_nlines_in_file(FILE *fd,PdsRaNatural *nc,PdsRaNatural *nl);
  *  \return TRUE si todo fue bien o FALSE si no. (ej. fd==NULL)
  *  \ingroup PdsRaUtilsGroup
  */
-int pds_ra_nelements_in_file(FILE *fd,PdsRaNatural *n);
+int pds_load_number_of_elements(FILE *fd,PdsRaNatural *n);
 
 /**
  * @}
