@@ -90,6 +90,44 @@ typedef struct
 PdsVector *pds_vector_new(PdsRaNatural Nel);
 
 
+/** \fn PdsVector *pds_vector_new_array1d(const PdsRaReal *Array1D,PdsRaNatural N)
+ *  \brief Crea un vector de tipo PdsVector e inicia sus valores con el contenido
+ *  del arreglo de valores reales Array1D.
+ *  
+ *  exemplo:
+\code{.c}
+    PdsVector *V=NULL;
+    PdsRaReal A[]={-1,1.2,-3.0};
+    V=pds_vector_new_array1d(A,3);
+\endcode
+ *  \warning { Debes tener mucho cuidado con esta función, entregando el número de elementos adecuado. }
+ *  \param[in] Array1D Es el arreglo unidimensional que se usará como fuente.
+ *  \param[in] N Es el número de elementos del arreglo unidimensional que se usará como fuente.
+ *  \return Un puntero al vector de tipo PdsVector.
+ *  \ingroup PdsVectorGroup
+ */
+PdsVector *pds_vector_new_array1d(const PdsRaReal *Array1D,PdsRaNatural N);
+
+
+/** \fn PdsVector *pds_vector_new_args(PdsRaNatural N,...)
+ *  \brief Crea un vector de tipo PdsVector e inicia sus valores con los valores
+ *  del segundo parametro de entrada en adelante.
+ *  
+ *  exemplo:
+\code{.c}
+    PdsVector *V=NULL;
+    V=pds_vector_new_args(3,-1,1.2,-3.0);
+\endcode
+ *  \warning { Debes tener mucho cuidado con esta función, entregando el número de elementos adecuado. }
+ *  \param[in] N Es el número de elementos del vector y el numero de parametros
+ *  de entrada adicionales.
+ *  \param[in] ... Parametros adicionales de tipo double.
+ *  \return Un puntero al vector de tipo PdsVector.
+ *  \ingroup PdsVectorGroup
+ */
+PdsVector *pds_vector_new_args(PdsRaNatural N,...);
+
+
 /** \fn PdsVector *pds_vector_new_vector(const PdsVector *VecSrc)
  *  \brief Crea un vector de tipo PdsVector e inicia sus valores con el contenido
  *  de el vector VecSrc.
@@ -658,6 +696,25 @@ PdsVector *pds_vector_new_hamming(PdsRaNatural N);
 PdsVector *pds_vector_new_blackman(PdsRaNatural N,PdsRaReal Alpha);
 
 
+/** \fn int pds_vector_octave_png_plot(const PdsVector *X,const PdsVector *Y,const char *labelx,const char *labely,const char *octfile,const char *pngfile)
+ *  \brief Imprime un vector Y vs X en un archivo png usando como intermedio un 
+ *  archivo *.m de octave.
+ *  \param[in] X Eje X del vector a imprimir.
+ *  Si X==NULL entonces se mostrara la gráfica usando el numero de muestras
+ *  como eje X.
+ *  \param[in] Y Eje Y del vector a imprimir.
+ *  \param[in] labelx Etiqueta del eje X.
+ *  \param[in] labely Etiqueta del eje Y.
+ *  \param[in] octfile Nombre del archivo *.m de octave que se usará de intermediario.
+ *  Si ostfile==NULL entonces se creará un fichero con nombre aleatorio y se 
+ *  borrará al terminar de crear el archivo png.
+ *  \param[in] pngfile Nombre del archivo *.png de salida.
+ *  \return TRUE si todo fue bien o FALSE si no, ejemplo punteros igual a NULL.
+ *  \ingroup PdsVectorGroup
+ */
+int pds_vector_octave_png_plot(const PdsVector *X,const PdsVector *Y,const char *labelx,const char *labely,const char *octfile,const char *pngfile);
+
+
 /** \fn void pds_vector_free(PdsVector *Vector)
  *  \brief Libera la memoria de un vector de tipo puntero PdsVector.
  *  \param[in,out] Vector El vector a liberar.
